@@ -1,18 +1,4 @@
-"""Copyright (c) 2006-2020 by the respective copyright holders.
-
-See the NOTICE file(s) distributed with this work for additional
-information.
-
-This program and the accompanying materials are made available under the
-terms of the Eclipse Public License 2.0 which is available at
-http://www.eclipse.org/legal/epl-2.0
-
-SPDX-License-Identifier: EPL-2.0
-
-Contributors:
-  Andre Lengwenus - port to Python and further improvements
-  Tobias Juettner - initial LCN binding for openHAB (Java)
-"""
+"""Parsers for incoming PCK messages."""
 
 import logging
 from typing import List, Optional, Tuple, Type
@@ -870,6 +856,7 @@ class ModStatusAccessControl(ModInput):
         level: Optional[int] = None,
         key: Optional[int] = None,
         action: Optional[lcn_defs.KeyAction] = None,
+        battery: Optional[lcn_defs.BatteryStatus] = None,
     ):
         """Construct ModInput object."""
         super().__init__(physical_source_addr)
@@ -878,6 +865,7 @@ class ModStatusAccessControl(ModInput):
         self.level = level
         self.key = key
         self.action = action
+        self.battery = battery
 
     @staticmethod
     def try_parse(data: str) -> Optional[List[Input]]:
@@ -904,13 +892,24 @@ class ModStatusAccessControl(ModInput):
             key = int(matcher.group("key")) - 1
 
             actions = {
-                "011": lcn_defs.KeyAction.HIT,
-                "012": lcn_defs.KeyAction.MAKE,
-                "013": lcn_defs.KeyAction.BREAK,
+                "1": lcn_defs.KeyAction.HIT,
+                "2": lcn_defs.KeyAction.MAKE,
+                "3": lcn_defs.KeyAction.BREAK,
             }
 
-            action = actions[matcher.group("action")]
-            return [ModStatusAccessControl(addr, periphery, code, level, key, action)]
+            battery_status = {
+                "0": lcn_defs.BatteryStatus.FULL,
+                "1": lcn_defs.BatteryStatus.WEAK,
+            }
+
+            action = actions[matcher.group("action")[2]]
+            battery = battery_status[matcher.group("action")[1]]
+
+            return [
+                ModStatusAccessControl(
+                    addr, periphery, code, level, key, action, battery
+                )
+            ]
 
         matcher = PckParser.PATTERN_STATUS_TRANSPONDER.match(data)
         if matcher:
@@ -934,6 +933,17 @@ class ModStatusAccessControl(ModInput):
             )
             return [ModStatusAccessControl(addr, periphery, code)]
 
+        matcher = PckParser.PATTERN_STATUS_CODELOCK.match(data)
+        if matcher:
+            periphery = lcn_defs.AccessControlPeriphery.CODELOCK
+            addr = LcnAddr(int(matcher.group("seg_id")), int(matcher.group("mod_id")))
+            code = (
+                f"{int(matcher.group('code1')):02x}"
+                f"{int(matcher.group('code2')):02x}"
+                f"{int(matcher.group('code3')):02x}"
+            )
+            return [ModStatusAccessControl(addr, periphery, code)]
+
         return None
 
 
