@@ -1,18 +1,4 @@
-"""Copyright (c) 2006-2020 by the respective copyright holders.
-
-See the NOTICE file(s) distributed with this work for additional
-information.
-
-This program and the accompanying materials are made available under the
-terms of the Eclipse Public License 2.0 which is available at
-http://www.eclipse.org/legal/epl-2.0
-
-SPDX-License-Identifier: EPL-2.0
-
-Contributors:
-  Andre Lengwenus - port to Python and further improvements
-  Tobias Juettner - initial LCN binding for openHAB (Java)
-"""
+"""Definitions and constants for pypck."""
 
 import math
 import re
@@ -163,6 +149,13 @@ class KeyAction(Enum):
     BREAK = "break"
 
 
+class BatteryStatus(Enum):
+    """Battery status."""
+
+    WEAK = "weak"
+    FULL = "full"
+
+
 class OutputPortDimMode(Enum):
     """LCN dimming mode.
 
@@ -1377,6 +1370,7 @@ class AccessControlPeriphery(Enum):
     TRANSMITTER = "transmitter"
     TRANSPONDER = "transponder"
     FINGERPRINT = "fingerprint"
+    CODELOCK = "codelock"
 
 
 default_connection_settings: Dict[str, Any] = {
