@@ -1,18 +1,4 @@
-"""Copyright (c) 2006-2020 by the respective copyright holders.
-
-See the NOTICE file(s) distributed with this work for additional
-information.
-
-This program and the accompanying materials are made available under the
-terms of the Eclipse Public License 2.0 which is available at
-http://www.eclipse.org/legal/epl-2.0
-
-SPDX-License-Identifier: EPL-2.0
-
-Contributors:
-  Andre Lengwenus - port to Python and further improvements
-  Tobias Juettner - initial LCN binding for openHAB (Java)
-"""
+"""Module and group classes."""
 
 import asyncio
 from typing import (
