@@ -1,18 +1,4 @@
-"""Copyright (c) 2006-2020 by the respective copyright holders.
-
-See the NOTICE file(s) distributed with this work for additional
-information.
-
-This program and the accompanying materials are made available under the
-terms of the Eclipse Public License 2.0 which is available at
-http://www.eclipse.org/legal/epl-2.0
-
-SPDX-License-Identifier: EPL-2.0
-
-Contributors:
-  Andre Lengwenus - port to Python and further improvements
-  Tobias Juettner - initial LCN binding for openHAB (Java)
-"""
+"""PCK command parsers and generators."""
 
 import re
 from typing import List, Optional, Sequence
@@ -195,6 +181,12 @@ class PckParser:
         r"(?P<code1>\d{3})(?P<code2>\d{3})(?P<code3>\d{3})"
     )
 
+    # Pattern to parse codelock status messages.
+    PATTERN_STATUS_CODELOCK = re.compile(
+        r"=M(?P<seg_id>\d{3})(?P<mod_id>\d{3})\.ZC"
+        r"(?P<code1>\d{3})(?P<code2>\d{3})(?P<code3>\d{3})"
+    )
+
     @staticmethod
     def get_boolean_value(input_byte: int) -> List[bool]:
         """Get boolean representation for the given byte.
